@@ -132,8 +132,8 @@ class BasePolynomial(ExplicitCurve):
             self.set_coef(coef)
             # self.coef = np.array(coef)
             # self.order = self.coef.shape[0] - 1
-            # for i in range(1,4): # 先求1-3阶导数
-            #     self.derivative_coef(order=i)
+            # for index in range(1,4): # 先求1-3阶导数
+            #     self.derivative_coef(order=index)
 
         if valid_x_range is None:
             self.valid_x_range = [-np.inf, np.inf]
@@ -775,7 +775,7 @@ class myCubicSpline(InterpolationCurve):
 
     def _search_index(self, x):
         """
-        search data segment index
+        search data segment record_index
         """
         if self._isscalar(x):
             pt_idx = bisect.bisect(self.x, x) - 1  # 二分查找插入点的索引
@@ -804,13 +804,13 @@ class myCubicSpline(InterpolationCurve):
         else:
             val = 0.
         # if order == 0:
-        #     val = self.a[i] + self.b[i] * dx + self.c[i] * dx ** 2.0 + self.d[i] * dx ** 3.0
+        #     val = self.a[index] + self.b[index] * dx + self.c[index] * dx ** 2.0 + self.d[index] * dx ** 3.0
         # elif order == 1:
-        #     val = self.b[i] + 2.0 * self.c[i] * dx + 3.0 * self.d[i] * dx ** 2.0
+        #     val = self.b[index] + 2.0 * self.c[index] * dx + 3.0 * self.d[index] * dx ** 2.0
         # elif order == 2:
-        #     val = 2.0 * self.c[i] + 6.0 * self.d[i] * dx
+        #     val = 2.0 * self.c[index] + 6.0 * self.d[index] * dx
         # elif order == 3:
-        #     val = 6.0 * self.d[i]
+        #     val = 6.0 * self.d[index]
         # else:
         #     val = 0.
         return val
@@ -877,10 +877,10 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #         self.c = np.linalg.solve(A, B)
 #
 #         # calc spline coefficient b and d
-#         for i in range(self.nx - 1):
-#             self.d.append((self.c[i + 1] - self.c[i]) / (3.0 * h[i]))
-#             tb = (self.a[i + 1] - self.a[i]) / h[i] - h[i] * \
-#                  (self.c[i + 1] + 2.0 * self.c[i]) / 3.0
+#         for index in range(self.nx - 1):
+#             self.d.append((self.c[index + 1] - self.c[index]) / (3.0 * h[index]))
+#             tb = (self.a[index + 1] - self.a[index]) / h[index] - h[index] * \
+#                  (self.c[index + 1] + 2.0 * self.c[index]) / 3.0
 #             self.b.append(tb)
 #
 #     def calc(self, t):
@@ -895,9 +895,9 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #             return None
 #         elif t > self.x[-1]:
 #             return None
-#         i = self._search_index(t)
-#         dx = t - self.x[i]
-#         result = self.a[i] + self.b[i] * dx + self.c[i] * dx ** 2.0 + self.d[i] * dx ** 3.0
+#         index = self._search_index(t)
+#         dx = t - self.x[index]
+#         result = self.a[index] + self.b[index] * dx + self.c[index] * dx ** 2.0 + self.d[index] * dx ** 3.0
 #
 #         return result
 #
@@ -913,9 +913,9 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #         elif t > self.x[-1]:
 #             return None
 #
-#         i = self._search_index(t)
-#         dx = t - self.x[i]
-#         result = self.b[i] + 2.0 * self.c[i] * dx + 3.0 * self.d[i] * dx ** 2.0
+#         index = self._search_index(t)
+#         dx = t - self.x[index]
+#         result = self.b[index] + 2.0 * self.c[index] * dx + 3.0 * self.d[index] * dx ** 2.0
 #         return result
 #
 #     def calcdd(self, t):
@@ -928,14 +928,14 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #         elif t > self.x[-1]:
 #             return None
 #
-#         i = self._search_index(t)
-#         dx = t - self.x[i]
-#         result = 2.0 * self.c[i] + 6.0 * self.d[i] * dx
+#         index = self._search_index(t)
+#         dx = t - self.x[index]
+#         result = 2.0 * self.c[index] + 6.0 * self.d[index] * dx
 #         return result
 #
 #     def _search_index(self, x):
 #         """
-#         search data segment index
+#         search data segment record_index
 #         """
 #         return bisect.bisect(self.x, x) - 1
 #
@@ -945,11 +945,11 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #         """
 #         A = np.zeros((self.nx, self.nx))
 #         A[0, 0] = 1.0
-#         for i in range(self.nx - 1):
-#             if i != (self.nx - 2):
-#                 A[i + 1, i + 1] = 2.0 * (h[i] + h[i + 1])
-#             A[i + 1, i] = h[i]
-#             A[i, i + 1] = h[i]
+#         for index in range(self.nx - 1):
+#             if index != (self.nx - 2):
+#                 A[index + 1, index + 1] = 2.0 * (h[index] + h[index + 1])
+#             A[index + 1, index] = h[index]
+#             A[index, index + 1] = h[index]
 #
 #         A[0, 1] = 0.0
 #         A[self.nx - 1, self.nx - 2] = 0.0
@@ -962,9 +962,9 @@ class Spline:#Cubic CubicSpline class(abandoned)
 #         calc matrix B for spline coefficient c
 #         """
 #         B = np.zeros(self.nx)
-#         for i in range(self.nx - 2):
-#             B[i + 1] = 3.0 * (self.a[i + 2] - self.a[i + 1]) / \
-#                        h[i + 1] - 3.0 * (self.a[i + 1] - self.a[i]) / h[i]
+#         for index in range(self.nx - 2):
+#             B[index + 1] = 3.0 * (self.a[index + 2] - self.a[index + 1]) / \
+#                        h[index + 1] - 3.0 * (self.a[index + 1] - self.a[index]) / h[index]
 #         #  print(B)
 #
 #         return B
@@ -1145,8 +1145,8 @@ class BezierCurve(ParametricCurve):
         # if pre_calculation:
         #     # 提前计算二项式系数
         #     values = binom(self.n, np.arange(self.n+1))
-        #     for i, val in enumerate(values):
-        #         self._binom_coeff_dict[(self.n, i)] = val
+        #     for index, val in enumerate(values):
+        #         self._binom_coeff_dict[(self.n, index)] = val
         #     # 提前计算
 
     @property
